==> owncloud-5.0.17.tar.bz2: owncloud/apps/contacts/l10n/lv.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Kļūda, (de)aktivizējot adrešu grāmatu.",
"id is not set." => "id nav iestatīts.",
"Cannot update addressbook with an empty name." => "Nevar atjaunināt adrešu grāmatu ar tukšu vārdu.",
"No category name given." => "Nav dots kategorijas nosaukums.",
"Error adding group." => "Kļūda, pievienojot grupu.",
"Group ID missing from request." => "Pieprasījumā pietrūkst grupas ID.",
"Contact ID missing from request." => "Pieprasījumā pietrūkst kontakta ID.",
"No ID provided" => "Nav norādīts ID",
"Error setting checksum." => "Kļūda, iestatot kontrolsummu.",
"No categories selected for deletion." => "Neviena kategorija nav izvēlēta dzēšanai.",
"No address books found." => "Nav atrastu adrešu grāmatu.",
"No contacts found." => "Nav atrastu kontaktu.",
"element name is not set." => "elementa nosaukums nav iestatīts.",
"checksum is not set." => "kontrolsumma nav iestatīta.",
"Information about vCard is incorrect. Please reload the page." => "Informācija par vCard ir nepareiza. Lūdzu, pārlādējiet šo lapu.",
"Couldn't find vCard for %d." => "Nevarēja atrast %d vCard.",
"Information about vCard is incorrect. Please reload the page: " => "Informācija par vCard ir nepareiza. Lūdzu, pārlādējiet lapu:",
"Something went FUBAR. " => "Kaut kas sagāja reālā sviestā.",
"Cannot save property of type \"%s\" as array" => "Nevarēja saglabāt īpašību ar tipu “%s” kā masīvu",
"Missing IM parameter." => "Trūkst TZ parametra.",
"Unknown IM: " => "Nezināms TZ:",
"No contact ID was submitted." => "Netika iesniegts kontakta ID. ",
"Error reading contact photo." => "Kļūda, nolasot kontakta fotogrāfiju.",
"Error saving temporary file." => "Kļūda, saglabājot pagaidu datni.",
"The loading photo is not valid." => "Ielādes fotogrāfija nav derīga.",
"Contact ID is missing." => "Trūkst kontakta ID.",
"No photo path was submitted." => "Nav iesniegts fotogrāfijas ceļš.",
"File doesn't exist:" => "Datne neeksistē:",
"Error loading image." => "Kļūda, ielādējot attēlu.",
"Error getting contact object." => "Kļūda, saņemot kontakta objektu.",
"Error getting PHOTO property." => "Kļūda, saņemot PHOTO īpašību.",
"Error saving contact." => "Kļūda, saglabājot kontaktu.",
"Error resizing image" => "Kļūda, mainot attēla izmēru",
"Error cropping image" => "Kļūda, apcērtot attēlu",
"Error creating temporary image" => "Kļūda, veidojot pagaidu attēlu",
"Error finding image: " => "Kļūda, meklējot attēlu:",
"Key is not set for: " => "Atslēga nav iestatīta:",
"Value is not set for: " => "Vēstība nav iestatīta:",
"Could not set preference: " => "Nevarēja iestatīt iestatījumu:",
"Error uploading contacts to storage." => "Kļūda, augšupielādējot kontaktus uz krātuvi.",
"There is no error, the file uploaded with success" => "Viss kārtībā, datne augšupielādēta veiksmīga",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Augšupielādētā datne pārsniedz upload_max_filesize direktīvu datnē php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Augšupielādētā datne pārsniedz MAX_FILE_SIZE norādi, kas ir norādīta HTML formā",
"The uploaded file was only partially uploaded" => "Augšupielādētā datne ir tikai daļēji augšupielādēta",
"No file was uploaded" => "Neviena datne netika augšupielādēta",
"Missing a temporary folder" => "Trūkst pagaidu mapes",
"Couldn't save temporary image: " => "Nevar saglabāt pagaidu attēlu:",
"Couldn't load temporary image: " => "Nevarēja ielādēt pagaidu attēlu:",
"No file was uploaded. Unknown error" => "Netika augšupielādēta neviena datne. Nezināma kļūda",
"Contacts" => "Kontakti",
"%d_selected_contacts" => "%d_izvēlētu_kontaktu",
"Add to..." => "Pievienot pie...",
"Remove from..." => "Izņemt no...",
"Add group..." => "Pievienot grupu...",
"Indexing contacts" => "Indeksē kontaktus",
"Select photo" => "Izvēlieties fotogrāfiju",
"Network or server error. Please inform administrator." => "Tīkla vai servera kļūda. Lūdzu, informējiet administratoru.",
"Error adding to group." => "Kļūda, pievienojot grupai.",
"Error removing from group." => "Kļūda, izņemot no grupas.",
"There was an error opening a mail composer." => "Gadījās kļūda, atverot vēstules redaktoru.",
"Deleting done. Click here to cancel reloading." => "Dzēšana ir pabeigta. Spiediet šeit, lai beigtu pārlādēt.",
"Add address book" => "Pievienot adrešu grāmatu",
"Import done. Click here to cancel reloading." => "Importēšana ir pabeigta. Spiediet šeit, lai beigtu pārlādēt.",
"Not all files uploaded. Retrying..." => "Ne visas datnes ir augšupielādētas. Mēģina vēlreiz...",
"Something went wrong with the upload, please retry." => "Kaut kas nogāja greizi ar augšupielādēšanu. Lūdzu, mēģiniet vēlreiz.",
"Error" => "Kļūda",
"Importing from {filename}..." => "Importē no {filename}...",
"{success} imported, {failed} failed." => "{success} importēti, {failed} cieta neveiksmi.",
"Importing..." => "Importē...",
"Unable to upload your file as it is a directory or has 0 bytes" => "Nevar augšupielādēt jūsu datni, jo tā ir direktorija vai arī tā ir 0 baitu liela",
"Upload Error" => "Augšupielādes kļūda",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Datne, ko mēģināt augšupielādēt pārsniedz maksimālo datņu augšupielādes izmēru šim serverim.",
"Upload too large" => "Datne ir par lielu, lai to augšupielādētu",
"Pending" => "Gaida savu kārtu",
"Add group" => "Pievienot grupu",
"No files selected for upload." => "Neviena datne nav izvēlēta augšupielādei.",
"Edit profile picture" => "Rediģēt profila bildi",
"Error loading profile picture." => "Kļūda, ielādējot profila bildi.",
"Enter name" => "Ievadiet vārdu",
"Enter description" => "Ievadiet aprakstu",
"Select addressbook" => "Izvēlieties adrešu grāmatu",
"The address book name cannot be empty." => "Adrešu grāmatas nosaukums nedrīkst būt tukšs.",
"Is this correct?" => "Vai tas ir pareizi?",
"There was an unknown error when trying to delete this contact" => "Gadījās nezināma kļūda, mēģinot dzēst šo kontaktu",
"# groups" => "# grupas",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Daži kontakti ir atzīmēti dzēšanai, bet vēl nav izdzēsti. Lūdzu, uzgaidiet, līdz tie tiks izdzēsti.",
"Click to undo deletion of {num} contacts" => "Spiediet, lai atsauktu {num} kontaktu dzēšanu",
"Cancelled deletion of {num}" => "Atcēla {num} dzēšanu",
"Contact is already in this group." => "Kontakts jau ir šajā grupā.",
"Contacts are already in this group." => "Kontakti jau ir šajā grupā.",
"Couldn't get contact list." => "Nevarēja saņemt kontaktu sarakstu.",
"Contact is not in this group." => "Kontakts nav šajā grupā.",
"Contacts are not in this group." => "Kontakti nav šajā grupā.",
"A group named {group} already exists" => "Grupa “{group}” jau eksistē",
"You can drag groups to\narrange them as you like." => "Jūs varat vilkt grupas,\nlai izkārtotu tās pēc savas patikas.",
"All" => "Visi",
"Favorites" => "Iecienītie",
"Shared by {owner}" => "Dalījās {owner}",
"Result: " => "Rezultāts:",
" imported, " => "importēts,",
" failed." => "cieta neveiksmi.",
"Displayname cannot be empty." => "Redzamais vārds nedrīkst būt tukšs.",
"Show CardDav link" => "Rādīt CardDav saiti",
"Show read-only VCF link" => "Rādīt tikai lasāmu VCF saiti",
"Download" => "Lejupielādēt",
"Edit" => "Rediģēt",
"Delete" => "Dzēst",
"Cancel" => "Atcelt",
"More..." => "Vairāk...",
"Less..." => "Mazāk...",
"You do not have the permissions to read this addressbook." => "Jums nav tiesību lasīt šo adrešu grāmatu.",
"You do not have the permissions to update this addressbook." => "Jums nav tiesību atjaunināt šo adrešu grāmatu.",
"There was an error updating the addressbook." => "Gadījās kļūda, atjauninot adrešu grāmatu.",
"You do not have the permissions to delete this addressbook." => "Jums nav tiesību dzēst šo adrešu grāmatu.",
"There was an error deleting this addressbook." => "Gadījās kļūda, dzēšot šo adrešu grāmatu.",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Darbs",
"Home" => "Mājas",
"Other" => "Cits",
"Mobile" => "Mobilais",
"Text" => "Teksts",
"Voice" => "Balss",
"Message" => "Ziņojums",
"Fax" => "Fakss",
"Video" => "Video",
"Pager" => "Peidžeris",
"Internet" => "Internets",
"Friends" => "Draugi",
"Family" => "Ģimene",
"There was an error deleting properties for this contact." => "Gadījās kļūda, dzēšot īpašības šim kontaktam.",
"{name}'s Birthday" => "{name} dzimšanas diena",
"Contact" => "Kontakts",
"You do not have the permissions to add contacts to this addressbook." => "Jums nav tiesību pievienot kontaktus šai adrešu grāmatai.",
"Could not find the vCard with ID." => "Nevarēja atrast vCard ar ID.",
"You do not have the permissions to edit this contact." => "Jums nav tiesību rediģēt šo kontaktu.",
"Could not find the vCard with ID: " => "Nevarēja atrast vCard ar ID:",
"Could not find the Addressbook with ID: " => "Nevarēja atrast adrešu grāmatu ar ID.",
"You do not have the permissions to delete this contact." => "Jums nav tiesību dzēst šo kontaktu.",
"There was an error deleting this contact." => "Gadījās kļūda, dzēšot šo kontaktu.",
"Contact not found." => "Kontakts nav atrasts.",
"HomePage" => "Mājas lapa",
"New Group" => "Jauna grupa",
"Settings" => "Iestatījumi",
"Address books" => "Adrešu grāmatas",
"Import" => "Importēt",
"Select files to import" => "Izvēlieties datnes, ko importēt",
"Select files" => "Izvēlieties datnes",
"Import into:" => "Importēt uz:",
"OK" => "Labi",
"(De-)select all" => "Izvēlēties visu/neko",
"New Contact" => "Jauns kontakts",
"Download Contact(s)" => "Lejupielādēt kontaktu(-s)",
"Groups" => "Grupas",
"Favorite" => "Iecienītais",
"Delete Contact" => "Dzēst kontaktu",
"Close" => "Aizvērt",
"Keyboard shortcuts" => "Tastatūras saīsnes",
"Navigation" => "Navigācija",
"Next contact in list" => "Nākošais kontakts sarakstā",
"Previous contact in list" => "Iepriekšējais kontakts sarakstā",
"Expand/collapse current addressbook" => "Izvērst/sakļaut pašreizējo adrešu grāmatu",
"Next addressbook" => "Nākošā adrešu grāmata",
"Previous addressbook" => "Iepriekšējā adrešu grāmata",
"Actions" => "Darbības",
"Refresh contacts list" => "Atsvaidzināt kontaktu sarakstu",
"Add new contact" => "Pievienot jaunu kontaktu",
"Add new addressbook" => "Pievienot jaunu adrešu grāmatu",
"Delete current contact" => "Dzēst pašreizējo kontaktu",
"<h3>You have no contacts in your addressbook.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>Jūsu adrešu grāmatā nav kontaktu.</h3><p>Pievieno jaunu kontaktu vai importē esošos kontaktus no VCF datnes.</p>",
"Add contact" => "Pievienot kontaktu",
"Compose mail" => "Sacerēt vēstuli",
"Delete group" => "Dzēst grupu",
"Delete current photo" => "Dzēst pašreizējo fotogrāfiju",
"Edit current photo" => "Rediģēt pašreizējo fotogrāfiju",
"Upload new photo" => "Augšupielādēt jaunu fotogrāfiju",
"Select photo from ownCloud" => "Izvēlieties fotogrāfiju no ownCloud",
"First name" => "Vārds",
"Additional names" => "Papildu vārdi",
"Last name" => "Uzvārds",
"Select groups" => "Izvēlieties grupas",
"Nickname" => "Iesauka",
"Enter nickname" => "Ievadiet iesauku",
"Title" => "Nosaukums",
"Enter title" => "Ievadiet nosaukumu",
"Organization" => "Organizācija",
"Enter organization" => "Ievadiet organizāciju",
"Birthday" => "Dzimšanas diena",
"Notes go here..." => "Piezīmes atrodas šeit...",
"Export as VCF" => "Eksportēt kā VCF",
"Add" => "Pievienot",
"Phone" => "Tālrunis",
"Email" => "E-pasts",
"Instant Messaging" => "Tūlītējā ziņojumapmaiņa",
"Address" => "Adrese",
"Note" => "Piezīme",
"Web site" => "Tīmekļa vietne",
"Delete contact" => "Dzēst kontaktu",
"Preferred" => "Vēlamais",
"Please specify a valid email address." => "Lūdzu, norādiet derīgu e-pasta adresi.",
"someone@example.com" => "kāds@piemērs.lv",
"Mail to address" => "Vēstule uz adresi",
"Delete email address" => "Dzēst e-pasta adresi",
"Enter phone number" => "Ievadiet tālruņa numuru",
"Delete phone number" => "Dzēst tālruņa numuru",
"Go to web site" => "Doties uz tīmekļa vietni",
"Delete URL" => "Dzēst URL",
"View on map" => "Skatīt kartē",
"Delete address" => "Dzēst adresi",
"1 Main Street" => "Brīvības iela 1",
"Street address" => "Ielas adrese",
"12345" => "12345",
"Postal code" => "Pasta kods",
"Your city" => "Tava pilsēta",
"City" => "Pilsēta",
"Some region" => "Kāds reģions",
"State or province" => "Štats vai province",
"Your country" => "Tava valsts",
"Country" => "Valsts",
"Instant Messenger" => "Tūlītējās ziņojumapmaiņas programma",
"Delete IM" => "Dzēst TZ",
"Share" => "Dalīties",
"Export" => "Eksportēt",
"CardDAV link" => "CardDAV saite",
"The temporary image has been removed from cache." => "Pagaidu attēls ir izņemts no kešatmiņas.",
"CardDAV syncing addresses" => "CardDAV sinhronizēšanas adreses",
"more info" => "vairāk informācijas",
"Primary address (Kontact et al)" => "Primārā adrese",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Adrešu grāmatas",
"New Address Book" => "Jauna adrešu grāmata",
"Name" => "Nosaukums",
"Description" => "Apraksts",
"Save" => "Saglabāt"
);

==> owncloud_7.0.11~dfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/lv.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Kontakti",
"Ok" => "Labi",
"Cancel" => "Atcelt",
"Save" => "Saglabāt",
"Error." => "Kļūda.",
"Remove from..." => "Izņemt no...",
"Add group..." => "Pievienot grupu...",
"Select photo" => "Izvēlieties fotogrāfiju",
"Network or server error. Please inform administrator." => "Tīkla vai servera kļūda. Lūdzu, informējiet administratoru.",
"Error adding to group." => "Kļūda, pievienojot grupai.",
"Error removing from group." => "Kļūda, izņemot no grupas.",
"Add group" => "Pievienot grupu",
"OK" => "Labi",
"# groups" => "# grupas",
"Add" => "Pievienot",
"All" => "Visi",
"Favorites" => "Iecienītie",
"Shared by {owner}" => "Dalījās {owner}",
"Import" => "Importēt",
"Importing..." => "Importē...",
"Close" => "Aizvērt",
"Contact not found" => "Kontakts netika atrasts",
"Unknown error" => "Nezināma kļūda",
"Access denied" => "Pieeja liegta",
"Error creating address book" => "Kļūda veidojot ",
"Error creating contact." => "Kļūda, veidojot kontaktu.",
"Error creating contact" => "Kļūda izveidojot kontaktu",
"Error deleting contact" => "Kļūda dzēšot kontaktu",
"No photo path was submitted." => "Nav iesniegts fotogrāfijas ceļš.",
"Error getting PHOTO property." => "Kļūda, saņemot PHOTO īpašību.",
"Error saving contact." => "Kļūda, saglabājot kontaktu.",
"No file was uploaded. Unknown error" => "Netika augšupielādēta neviena datne. Nezināma kļūda",
"There is no error, the file uploaded with success" => "Viss kārtībā, datne augšupielādēta veiksmīga",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Augšupielādētā datne pārsniedz MAX_FILE_SIZE norādi, kas ir norādīta HTML formā",
"The uploaded file was only partially uploaded" => "Augšupielādētā datne ir tikai daļēji augšupielādēta",
"No file was uploaded" => "Neviena datne netika augšupielādēta",
"Missing a temporary folder" => "Trūkst pagaidu mapes",
"Failed to write to disk" => "Neizdevās saglabāt diskā",
"Not enough storage available" => "Nav pietiekami daudz vietas",
"Contact" => "Kontakts",
"Other" => "Cits",
"HomePage" => "Mājas lapa",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Darbs",
"Home" => "Mājas",
"Mobile" => "Mobilais",
"Text" => "Teksts",
"Voice" => "Balss",
"Message" => "Ziņa",
"Fax" => "Fakss",
"Video" => "Video",
"Internet" => "Internets",
"Friends" => "Draugi",
"Family" => "Ģimene",
"New contact" => "Jauns kontakts",
"New group" => "Jauna grupa",
"Address books" => "Adrešu grāmatas",
"Delete" => "Dzēst",
"Groups" => "Grupas",
"Download" => "Lejupielādēt",
"Email" => "E-pasts",
"Phone" => "Tālrunis",
"Address" => "Adrese",
"Group" => "Grupa",
"Keyboard shortcuts" => "Tastatūras saīsnes",
"Navigation" => "Navigācija",
"Next contact in list" => "Nākamais kontakts sarakstā",
"Previous contact in list" => "Iepriekšējais kontakts sarakstā",
"Add new contact" => "Pievienot jaunu kontaktu",
"Add new addressbook" => "Pievienot jaunu adrešu grāmatu",
"Delete current contact" => "Dzēst pašreizējo kontaktu",
"Delete current photo" => "Dzēst pašreizējo fotogrāfiju",
"Edit current photo" => "Rediģēt pašreizējo fotogrāfiju",
"Upload new photo" => "Augšupielādēt jaunu fotogrāfiju",
"Favorite" => "Iecienītais",
"Name" => "Nosaukums",
"First name" => "Vārds",
"Additional names" => "Papildu vārdi",
"Last name" => "Uzvārds",
"Nickname" => "Iesauka",
"Title" => "Nosaukums",
"Organization" => "Organizācija",
"Birthday" => "Dzimšanas diena",
"Website" => "Mājaslapa",
"Instant messaging" => "Tūlītējā ziņojumapmaiņa",
"Notes go here..." => "Piezīmes atrodas šeit...",
"Add field..." => "Pievienot lauku...",
"Instant Messaging" => "Tūlītējā ziņojumapmaiņa",
"Note" => "Piezīme",
"Web site" => "Tīmekļa vietne",
"Preferred" => "Vēlamais",
"Please specify a valid email address." => "Lūdzu, norādiet derīgu e-pasta adresi.",
"someone@example.com" => "kāds@piemērs.lv",
"Mail to address" => "Vēstule uz adresi",
"Delete email address" => "Dzēst e-pasta adresi",
"Enter phone number" => "Ievadiet tālruņa numuru",
"Go to web site" => "Doties uz tīmekļa vietni",
"View on map" => "Skatīt kartē",
"Street address" => "Ielas adrese",
"Postal code" => "Pasta kods",
"City" => "Pilsēta",
"Country" => "Valsts",
"Instant Messenger" => "Tūlītējās ziņojumapmaiņas programma",
"Active" => "Aktīvs",
"Share" => "Dalīties",
"Export" => "Eksportēt",
"CardDAV link" => "CardDAV saite",
"Edit" => "Rediģēt",
"Description" => "Apraksts",
"User" => "Lietotājs",
"Password" => "Parole",
"Base DN" => "Bāzes DN"
);
